@@ -18,6 +18,8 @@ class SplintTestMethods using Moose {
     }
 }
 
+1;
+
 __END__
 
 =pod
@@ -26,6 +28,6 @@ __END__
 
 :splint classname SplintTestMethods
 
-::splint method a_test_method
+:splint method a_test_method
 
 :splint method another
